pub trait WaterInjectionTrait {
// Required method
fn inject_water(
&mut self,
refill_channels: &mut RefillChannels,
refill_errors: &mut RefillErrorStates,
sql_interface_refill: &mut Box<dyn DatabaseInterfaceRefillTrait + Sync + Send>,
mutex_tank_level_switch: &Arc<Mutex<TankLevelSwitchSignals>>,
) -> bool;
}Expand description
Trait for the execution of the refill once control has detected that the water level is low. This trait allows running the main control with a mock implementation for testing.